<?php

namespace Drupal\advanced_content_blocks;

use Drupal\Core\Block\BlockManagerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Routing\RedirectDestinationTrait;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;

/**
 * Manages block operations including creation and redirection.
 */
class BlockManager {
  use RedirectDestinationTrait;

  /**
   * The block manager service.
   *
   * @var \Drupal\Core\Block\BlockManagerInterface
   */
  protected $blockManager;

  /**
   * The configuration factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * The URL generator service.
   *
   * @var \Symfony\Component\Routing\Generator\UrlGeneratorInterface
   */
  protected $urlGenerator;

  public function __construct(BlockManagerInterface $block_manager, ConfigFactoryInterface $config_factory, EntityTypeManagerInterface $entity_type_manager, MessengerInterface $messenger, UrlGeneratorInterface $url_generator) {
    $this->blockManager = $block_manager;
    $this->configFactory = $config_factory;
    $this->entityTypeManager = $entity_type_manager;
    $this->messenger = $messenger;
    $this->urlGenerator = $url_generator;
  }

  /**
   * Adds a block and returns the URL for the block layout page.
   *
   * @param string $plugin_id
   *   The plugin ID of the block to add.
   *
   * @return string
   *   The URL to the block layout page or the current page if an error occurs.
   */
  public function addBlock($plugin_id) {
    try {
      // Create a block instance and redirect to the block layout page.
      $block = $this->entityTypeManager->getStorage('block')->create([
        'id' => strtolower($plugin_id) . '_block',
        'plugin' => $plugin_id,
        'theme' => \Drupal::theme()->getActiveTheme()->getName(),
        'status' => 1,
      ]);
      $block->save();

      $this->messenger->addMessage(t('The block has been added.'));
      $block_layout_url = $this->urlGenerator->generateFromRoute('block.admin_display', [], ['query' => $this->getDestinationArray()]);
      return $block_layout_url;
    }
    catch (\Exception $e) {
      $this->messenger->addError(t('The block could not be added: @message', ['@message' => $e->getMessage()]));
      return $this->urlGenerator->generateFromRoute('<current>');
    }
  }

}
