<?php

namespace Drupal\advanced_content_blocks\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'CalendarBlock' block.
 *
 * @Block(
 *   id = "calendar_block",
 *   admin_label = @Translation("Calendar Block"),
 * )
 */
class CalendarBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();
    $calendar_url = $config['calendar_url'] ?? '';

    \Drupal::logger('advanced_content_blocks')->notice('Calendar URL: @url', ['@url' => $calendar_url]);

    $build = [
      '#theme' => 'calendar_block',
      '#calendar_url' => $calendar_url,
    ];

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'calendar_url' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $config = $this->getConfiguration();

    $form['calendar_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Calendar URL'),
      '#description' => $this->t('Enter the public URL of the calendar.'),
      '#default_value' => $config['calendar_url'] ?? '',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->setConfigurationValue('calendar_url', $form_state->getValue('calendar_url'));
  }

  /**
   * {@inheritdoc}
   */
  public function blockValidate($form, FormStateInterface $form_state) {
    $calendar_url = $form_state->getValue('calendar_url');

    // Check if the calendar URL is empty.
    if (empty($calendar_url)) {
      $form_state->setErrorByName('calendar_url', $this->t('The Calendar URL field cannot be empty.'));
    }
  }

}
