<?php

namespace Drupal\advanced_content_blocks\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Contact Us' Block with address and phone number.
 *
 * @Block(
 *   id = "contact_us_block",
 *   admin_label = @Translation("Contact Us Block"),
 * )
 */
class ContactUsBlock extends BlockBase implements BlockPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();

    return [
      '#markup' => '<div class="contact-us">
            <p>' . $this->t('Address: @address', ['@address' => $config['address'] ?? '']) . '</p>
      <p>' . $this->t('Phone: @phone', ['@phone' => $config['phone'] ?? '']) . '</p>
    </div>',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();

    $form['address'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Address'),
      '#default_value' => $config['address'] ?? '',
      '#description' => $this->t('Enter the address.'),
    ];

    $form['phone'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Phone Number'),
      '#default_value' => $config['phone'] ?? '',
      '#description' => $this->t('Enter the phone number.'),
      '#validate' => ['::validatePhoneNumber'],
      '#attributes' => [
        'pattern' => '[0-9]+', // Allows only numbers.
        'title' => $this->t('Please enter a valid phone number with digits only.')
      ],
    ];


    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->setConfigurationValue('address', $form_state->getValue('address'));
    $this->setConfigurationValue('phone', $form_state->getValue('phone'));
  }

}
