<?php

namespace Drupal\advanced_content_blocks\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'SocialLinksBlock' block.
 *
 * @Block(
 *   id = "social_links_block",
 *   admin_label = @Translation("Social Links Block"),
 * )
 */
class SocialLinksBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();

    // Define the image paths.
    $image_paths = [
      'facebook' => 'modules/advanced_content_blocks/images/facebook.svg',
      'twitter' => 'modules/advanced_content_blocks/images/x-twitter.svg',
      'instagram' => 'modules/advanced_content_blocks/images/instagram.svg',
      'pinterest' => 'modules/advanced_content_blocks/images/pinterest.svg',
    ];

    return [
      '#markup' => '
      <div class="social-links-block">
        <a href="' . ($config['facebook_url'] ?? '#') . '" target="_blank">
          <img src="' . $image_paths['facebook'] . '" height="24" width="24" alt="Facebook"/>
        </a>
        <a href="' . ($config['twitter_url'] ?? '#') . '" target="_blank">
          <img src="' . $image_paths['twitter'] . '" height="24" width="24" alt="Twitter"/>
        </a>
        <a href="' . ($config['instagram_url'] ?? '#') . '" target="_blank">
          <img src="' . $image_paths['instagram'] . '" height="24" width="24" alt="Instagram"/>
        </a>
        <a href="' . ($config['pinterest_url'] ?? '#') . '" target="_blank">
          <img src="' . $image_paths['pinterest'] . '" height="24" width="24" alt="Pinterest"/>
        </a>
      </div>',
      '#attached' => [
        'library' => [
          'advanced_content_blocks/social_links',
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $config = $this->getConfiguration();

    $form['facebook_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Facebook URL'),
      '#default_value' => $config['facebook_url'] ?? '',
      '#description' => $this->t('Enter the URL for the Facebook link.'),
    ];

    $form['twitter_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Twitter URL'),
      '#default_value' => $config['twitter_url'] ?? '',
      '#description' => $this->t('Enter the URL for the Twitter link.'),
    ];

    $form['instagram_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Instagram URL'),
      '#default_value' => $config['instagram_url'] ?? '',
      '#description' => $this->t('Enter the URL for the Instagram link.'),
    ];

    $form['pinterest_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pinterest URL'),
      '#default_value' => $config['pinterest_url'] ?? '',
      '#description' => $this->t('Enter the URL for the Pinterest link.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->setConfigurationValue('facebook_url', $form_state->getValue('facebook_url'));
    $this->setConfigurationValue('twitter_url', $form_state->getValue('twitter_url'));
    $this->setConfigurationValue('instagram_url', $form_state->getValue('instagram_url'));
    $this->setConfigurationValue('pinterest_url', $form_state->getValue('pinterest_url'));
  }

}
